@@ -72,12 +72,11 @@ View::View(QWidget *parent)
     : QWidget(parent)
     , d(new ViewPrivate())
 {
-    d->logViewWidget = NULL;
+    d->logViewWidget = nullptr;
 
-    QVBoxLayout *topLayout = new QVBoxLayout();
+    QVBoxLayout *topLayout = new QVBoxLayout(this);
     topLayout->setMargin(2);
     topLayout->setSpacing(2);
-    this->setLayout(topLayout);
 
     d->logViewFilterWidget = new LogViewFilterWidget();
     connect(d->logViewFilterWidget->filterLine(), &LogViewWidgetSearchLine::treeWidgetUpdated, this,
@@ -176,7 +175,7 @@ void View::unselectHiddenItems()
 {
     QTreeWidgetItemIterator it(d->logViewWidget, QTreeWidgetItemIterator::Selected);
 
-    while (*it != NULL) {
+    while (*it != nullptr) {
         QTreeWidgetItem *item = *it;
 
         if (item->isHidden()) {
