@@ -56,19 +56,19 @@ public:
     {
     }
 
-    virtual ~KernelAnalyzerLocalReader() {}
+    ~KernelAnalyzerLocalReader() override {}
 
     QDateTime findStartupTime() { return startupDateTime; }
 
 protected:
-    LogFileReader *createLogFileReader(const LogFile &logFile) Q_DECL_OVERRIDE { return new LocalLogFileReader(logFile); }
+    LogFileReader *createLogFileReader(const LogFile &logFile) override { return new LocalLogFileReader(logFile); }
 };
 
 class KernelAnalyzerTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
 
     void initTestCase();
 
